@@ -21,7 +21,9 @@
 
 #include "controller_manager/controller_manager.hpp"
 #include "hardware_interface/resource_manager.hpp"
+#include "rclcpp/executor.hpp"
 #include "rclcpp/executors/single_threaded_executor.hpp"
+#include "rclcpp/utilities.hpp"
 #include "ros2_control_test_assets/descriptions.hpp"
 
 TEST(TestLoadTricycleController, load_controller)
